@@ -14,21 +14,24 @@
 #   See the License for the specific language governing permissions and
 #   limitations under the License.
 
-import cStringIO
+from __future__ import unicode_literals
 import logging
 import os
-import urllib2
 import warnings
 
 from lxml import etree
 from lxml.builder import ElementMaker
+import six
+from six.moves.urllib.request import urlopen
 
+from eulxml.utils.compat import u
 from eulxml.xmlmap.fields import Field
 
 logger = logging.getLogger(__name__)
 
 __all__ = ['XmlObject', 'parseUri', 'parseString', 'loadSchema',
-    'load_xmlobject_from_string', 'load_xmlobject_from_file']
+    'load_xmlobject_from_string', 'load_xmlobject_from_file',
+    'load_xslt']
 
 # NB: When parsing XML in this module, we explicitly create a new parser
 #   each time. Without this, lxml 2.2.7 uses a global default parser. When
@@ -114,6 +117,19 @@ def loadSchema(uri, base_uri=None, override_proxy_requirement=False):
         raise etree.XMLSchemaParseError('Failed to parse schema %s -- %s' % (error_uri, parse_err))
 
 
+def load_xslt(filename=None, xsl=None):
+    '''Load and compile an XSLT document (specified by filename or string)
+    for repeated use in transforming XML.
+    '''
+    parser = _get_xmlparser()
+    if filename is not None:
+        xslt_doc = etree.parse(filename, parser=parser)
+    if xsl is not None:
+        xslt_doc = etree.fromstring(xsl, parser=parser)
+
+    return etree.XSLT(xslt_doc)
+
+
 def _http_uri(uri):
     return uri.startswith('http:') or uri.startswith('https:')
 
@@ -174,7 +190,7 @@ class XmlObjectType(type):
         schema_obj = None
 
         for attr_name, attr_val in defined_attrs.items():
-            # XXX: not a fan of isintance here. maybe use something like
+            # XXX: not a fan of isinstance here. maybe use something like
             # django's contribute_to_class?
             if isinstance(attr_val, Field):
                 if isinstance(attr_val, SchemaField):
@@ -198,7 +214,7 @@ class XmlObjectType(type):
                 # collect self-referential NodeFields so that we can resolve
                 # them once we've created the new class
                 node_class = getattr(field, 'node_class', None)
-                if isinstance(node_class, basestring):
+                if isinstance(node_class, six.string_types):
                     if node_class in ('self', name):
                         recursive_fields.append(field)
                     else:
@@ -236,11 +252,12 @@ class XmlObjectType(type):
     def _make_create_field(field_name, field):
         def create_field(xmlobject):
             field.create_for_node(xmlobject.node, xmlobject.context)
-        create_field.__name__ = field_name
+        create_field.__name__ = str(field_name)
         return create_field
 
 
-class XmlObject(object):
+@six.python_2_unicode_compatible
+class XmlObject(six.with_metaclass(XmlObjectType, object)):
 
     """
     A Python object wrapped around an XML node.
@@ -265,8 +282,6 @@ class XmlObject(object):
     considered equal if they point to the same lxml element node.
     """
 
-    __metaclass__ = XmlObjectType
-
     node = None
     """The top-level xml node wrapped by the object"""
 
@@ -330,7 +345,7 @@ class XmlObject(object):
 
         # xpath has no notion of a default namespace - omit any namespace with no prefix
         self.context = {'namespaces': dict([(prefix, ns) for prefix, ns
-                                            in nsmap.iteritems() if prefix])}
+                                            in six.iteritems(nsmap) if prefix])}
 
         if context is not None:
             self.context.update(context)
@@ -338,7 +353,7 @@ class XmlObject(object):
             # also include any root namespaces to guarantee that expected prefixes are available
             self.context['namespaces'].update(self.ROOT_NAMESPACES)
 
-        for field, value in kwargs.iteritems():
+        for field, value in six.iteritems(kwargs):
             # TODO (maybe): handle setting/creating list fields
             setattr(self, field, value)
 
@@ -356,34 +371,64 @@ class XmlObject(object):
     def xsl_transform(self, filename=None, xsl=None, return_type=None, **params):
         """Run an xslt transform on the contents of the XmlObject.
 
-        XSLT can be passed as filename or string. If a params dictionary is
-        specified, its items will be passed as parameters to the XSL
-        transformation.
+        XSLT can be passed in as an XSLT object generated by :meth:`load_xslt`
+        or as filename or string. If a params dictionary is specified, its items
+        will be passed as parameters to the XSL transformation, and any string
+        values will automatically be encoded as XSL string parameters.
+
+        .. Note::
+
+            If XSL is being used multiple times, it is recommended to
+            use :meth`:load_xslt` to load and compile the XSLT once.
 
         :param filename: xslt filename (optional, one of file and xsl is required)
-        :param xsl: xslt as string (optional)
+        :param xsl: xslt as string OR compiled XSLT object as returned by
+            :meth:`load_xslt` (optional)
         :param return_type: type of object to return; optional, defaults to
             :class:`XmlObject`; specify unicode or string for text output
         :returns: an instance of :class:`XmlObject` or the return_type specified
         """
-        parser = _get_xmlparser()
-        if filename is not None:
-            xslt_doc = etree.parse(filename, parser=parser)
-        if xsl is not None:
-            xslt_doc = etree.fromstring(xsl, parser=parser)
-        transform = etree.XSLT(xslt_doc, **params)
         # NOTE: converting _XSLTResultTree to XmlObject because of a bug in its unicode method
         # - to output xml result, use serialize instead of unicode
         if return_type is None:
             return_type = XmlObject
 
-        result = transform(self.node)
+        # automatically encode any string params as XSLT string parameters
+        for key, val in six.iteritems(params):
+            if isinstance(val, six.string_types):
+                params[key] = etree.XSLT.strparam(val)
+
+        parser = _get_xmlparser()
+        # if a compiled xslt object is passed in, use that first
+        if xsl is not None and isinstance(xsl, etree.XSLT):
+            result = xsl(self.node, **params)
+        else:
+            # otherwise, load the xslt
+            if filename is not None:
+                xslt_doc = etree.parse(filename, parser=parser)
+            if xsl is not None:
+                xslt_doc = etree.fromstring(xsl, parser=parser)
+
+            # NOTE: there is a memory bug that results in malloc errors and
+            # segfaults when using the parsed etree.XSLT approach here.
+            # As a workaround, using the document xslt method instead.
+
+            if self.node == self.node.getroottree().getroot():
+                # if current node is root node, use entire document for transform
+                xmltree = self.node.getroottree()
+            else:
+                # otherwise, construct a temporary partial document from this node
+                partial_doc = etree.fromstring(self.serialize(), parser=parser)
+                xmltree = partial_doc.getroottree()
+
+            result = xmltree.xslt(xslt_doc, **params)
+
         # If XSLT returns nothing, transform returns an _XSLTResultTree
         # with no root node.  Log a warning, and don't generate an
         # empty xmlobject which will behave unexpectedly.
 
         # text output does not include a root node, so check separately
-        if return_type in [str, unicode]:
+        if issubclass(return_type, six.string_types):
             if result is None:
                 logger.warning("XSL transform generated an empty result")
                 return
@@ -396,15 +441,15 @@ class XmlObject(object):
             # pass in root node, rather than the result tree object
             return return_type(result.getroot())
 
-    def __unicode__(self):
-        if isinstance(self.node, basestring):
+    def __str__(self):
+        if isinstance(self.node, six.string_types):
             return self.node
         return self.node.xpath("normalize-space(.)")
 
     def __string__(self):
-        if isinstance(self.node, basestring):
+        if isinstance(self.node, six.string_types):
             return self.node
-        return unicode(self).encode('ascii', 'xmlcharrefreplace')
+        return u(self).encode('ascii', 'xmlcharrefreplace')
 
     def __eq__(self, other):
         # consider two xmlobjects equal if they are pointing to the same xml node
@@ -447,7 +492,7 @@ class XmlObject(object):
         # actual logic of xml serialization
         if stream is None:
             string_mode = True
-            stream = cStringIO.StringIO()
+            stream = six.BytesIO()
         else:
             string_mode = False
 
@@ -532,9 +577,12 @@ class Urllib2Resolver(etree.Resolver):
             url = 'file:' + url
 
         logger.debug('Resolving url %s' % url)
-        f = urllib2.urlopen(url, None, 10)
+        f = urlopen(url, None, 10)
         # set a timeout in case connection fails or is unreasonably slow
-        return self.resolve_file(f, context, base_url=url)
+        if f:
+            return self.resolve_file(f, context, base_url=url)
+        else:
+            return self.resolve_filename(url, context)
 _defaultResolver = Urllib2Resolver()
 
 
