@@ -14,13 +14,17 @@
 #   See the License for the specific language governing permissions and
 #   limitations under the License.
 
+from __future__ import unicode_literals
 from copy import deepcopy
 from datetime import datetime, date
 import logging
+
 from lxml import etree
 from lxml.builder import ElementMaker
+import six
+
+from eulxml.utils.compat import u
 from eulxml.xpath import ast, parse, serialize
-from types import ListType, FloatType
 
 __all__ = [
     'StringField', 'StringListField',
@@ -29,7 +33,7 @@ __all__ = [
     'ItemField', 'SimpleBooleanField',
     'DateTimeField', 'DateTimeListField',
     'DateField', 'DateListField',
-    'SchemaField',
+    'SchemaField','FloatField','FloatListField',
 ]
 
 logger = logging.getLogger(__name__)
@@ -90,7 +94,7 @@ class Mapper(object):
         if value is None:
             return value
         else:
-            return unicode(value)
+            return u(value)
 
 
 class StringMapper(Mapper):
@@ -102,7 +106,7 @@ class StringMapper(Mapper):
     def to_python(self, node):
         if node is None:
             return None
-        if isinstance(node, basestring):
+        if isinstance(node, six.string_types):
             return node
         return self.XPATH(node)
 
@@ -113,7 +117,7 @@ class IntegerMapper(Mapper):
             return None
         try:
             # xpath functions such as count return a float and must be converted to int
-            if isinstance(node, basestring) or isinstance(node, FloatType):
+            if isinstance(node, six.string_types) or isinstance(node, float):
                 return int(node)
 
             return int(self.XPATH(node))
@@ -121,6 +125,19 @@ class IntegerMapper(Mapper):
             # anything that can't be converted to an Integer
             return None
 
+class FloatMapper(Mapper):
+    XPATH = etree.XPath('number()')
+    def to_python(self, node):
+        if node is None:
+            return None
+        try:
+            if isinstance(node, six.string_types):
+                return float(node)
+
+            return float(self.XPATH(node))
+        except ValueError:
+            # anything that can't be converted to an Float
+            return None
 
 class SimpleBooleanMapper(Mapper):
     XPATH = etree.XPath('string()')
@@ -129,11 +146,16 @@ class SimpleBooleanMapper(Mapper):
         self.false = false
 
     def to_python(self, node):
-        if node is None and \
-                self.false is None:
-            return False
+        # handle node not present in xml first
+        if node is None:
+            # if false is configured as None, then missing node is False
+            if self.false is None:
+                return False
+            # otherwise, return None to signify boolean is unset
+            else:
+                return None
 
-        if isinstance(node, basestring):
+        if isinstance(node, six.string_types):
             value = node
         else:
             value = self.XPATH(node)
@@ -165,7 +187,7 @@ class DateTimeMapper(object):
     def to_python(self, node):
         if node is None:
             return None
-        if isinstance(node, basestring):
+        if isinstance(node, six.string_types):
             rep = node
         else:
             rep = self.XPATH(node)
@@ -187,9 +209,9 @@ class DateTimeMapper(object):
     def to_xml(self, dt):
         val = None
         if self.format is not None:
-            val = unicode(dt.strftime(self.format))
+            val = u(dt.strftime(self.format))
         else:
-            val = unicode(dt.isoformat())
+            val = u(dt.isoformat())
         return val
 
 
@@ -203,7 +225,7 @@ class DateMapper(DateTimeMapper):
     def to_python(self, node):
         if node is None:
             return None
-        if isinstance(node, basestring):
+        if isinstance(node, six.string_types):
             rep = node
         elif hasattr(node, 'text'):
             rep = node.text
@@ -245,7 +267,7 @@ def _find_terminal_step(xast):
 def _find_xml_node(xpath, node, context):
     #In some cases the this will return a value not a node
     matches = node.xpath(xpath, **context)
-    if matches and isinstance(matches, ListType):
+    if matches and isinstance(matches, list):
         return matches[0]
     elif matches:
         return matches
@@ -343,7 +365,7 @@ def _predicate_is_constructible(pred):
             if not _predicate_is_constructible(pred.left):
                 return False
             if not isinstance(pred.right,
-                    (int, long, basestring, ast.VariableReference)):
+                    (six.integer_types, six.string_types, ast.VariableReference)):
                 return False
 
     # otherwise, i guess we're ok
@@ -708,7 +730,7 @@ class NodeList(object):
 
     def _check_key_type(self, key):
         # check argument type for getitem, setitem, delitem
-        if not isinstance(key, (slice, int, long)):
+        if not isinstance(key, (slice, six.integer_types)):
             raise TypeError
         assert not isinstance(key, slice), "Slice indexing is not supported"
 
@@ -872,6 +894,34 @@ class StringListField(Field):
                 manager = NodeListManager(),
                 mapper = StringMapper(normalize=normalize), *args, **kwargs)
 
+class FloatField(Field):
+
+    """Map an XPath expression to a single Python float. If the XPath
+    expression evaluates to an empty NodeList, an FloatField evaluates to
+    `None`.
+
+    Supports setting values for attributes, empty nodes, or text-only nodes.
+    """
+
+    def __init__(self, xpath, *args, **kwargs):
+        super(FloatField, self).__init__(xpath,
+                manager = SingleNodeManager(),
+                mapper = FloatMapper(), *args, **kwargs)
+
+class FloatListField(Field):
+
+    """Map an XPath expression to a list of Python floats. If the XPath
+    expression evaluates to an empty NodeList, an IntegerListField evaluates to
+    an empty list.
+
+    Actual return type is :class:`~eulxml.xmlmap.fields.NodeList`, which can be
+    treated like a regular Python list, and includes set and delete functionality.
+    """
+
+    def __init__(self, xpath, *args, **kwargs):
+        super(FloatListField, self).__init__(xpath,
+                manager = NodeListManager(),
+                mapper = FloatMapper(), *args, **kwargs)
 
 class IntegerField(Field):
 
@@ -904,6 +954,7 @@ class IntegerListField(Field):
                 mapper = IntegerMapper(), *args, **kwargs)
 
 
+
 class SimpleBooleanField(Field):
 
     """Map an XPath expression to a Python boolean.  Constructor takes additional
@@ -1168,4 +1219,3 @@ class SchemaField(Field):
             return newfield
         else:
             raise Exception("basetype %s is not yet supported by SchemaField" % basetype)
-
