@@ -16,12 +16,20 @@
 
 #!/usr/bin/env python
 
+from __future__ import unicode_literals
 from lxml import etree
 import os
 import unittest
-from unittest2 import skipIf
+try:
+    from unittest import skipIf
+except ImportError:
+    from unittest2 import skipIf
 import tempfile
 
+from six import string_types
+from six.moves.builtins import str as text
+
+from eulxml.utils.compat import u
 import eulxml.xmlmap.core as xmlmap
 
 proxy_required = skipIf('HTTP_PROXY' not in os.environ,
@@ -79,15 +87,38 @@ class TestXsl(unittest.TestCase):
     </xsl:stylesheet>
     '''
 
+    PARAM_XSL = '''
+    <xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
+        <xsl:param name="input"/>
+        <xsl:template match="/" ><xsl:value-of select="$input"/></xsl:template>
+    </xsl:stylesheet>
+    '''
+
+    # identity transform
+    IDENTITY_XSL = '''
+    <xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
+        <xsl:template match="@*|node()">
+            <xsl:copy>
+                <xsl:apply-templates select="@*|node()"/>
+            </xsl:copy>
+        </xsl:template>
+    </xsl:stylesheet>'''
+
     def setUp(self):
         # parseString wants a url. let's give it a proper one.
         url = '%s#%s.%s' % (__file__, self.__class__.__name__, 'FIXTURE_TEXT')
         self.fixture = xmlmap.parseString(self.FIXTURE_TEXT, url)
+        self.FILE = None
+
+    def tearDown(self):
+        if self.FILE is not None:
+            self.FILE.close()
 
     def test_xsl_transform(self):
         class TestObject(xmlmap.XmlObject):
             bar_baz = xmlmap.StringField('bar[1]/baz')
             nobar_baz = xmlmap.StringField('baz[1]')
+            bar_node = xmlmap.NodeField('bar[1]', xmlmap.XmlObject)
 
         # xsl in string
         obj = TestObject(self.fixture)
@@ -117,11 +148,31 @@ class TestXsl(unittest.TestCase):
         self.assertEqual('42 13 ', result)
         self.assert_(isinstance(result, str))
 
-        result = obj.xsl_transform(xsl=self.TEXT_OUTPUT_XSL, return_type=unicode)
-        self.assert_(isinstance(result, unicode))
+        result = obj.xsl_transform(xsl=self.TEXT_OUTPUT_XSL, return_type=text)
+        self.assert_(isinstance(result, string_types))
+
+        # transform with parameters
+        obj = TestObject(self.fixture)
+        input_text = "some text content"
+        result = obj.xsl_transform(xsl=self.PARAM_XSL, return_type=str,
+            input=input_text)
+        self.assert_(input_text in result)
+
+        # pre-compiled xslt
+        identity_transform = xmlmap.load_xslt(xsl=self.IDENTITY_XSL)
+        result = obj.xsl_transform(xsl=identity_transform)
+        # after the identity transform, result should be xml-equivalent
+        self.assertEqual(obj, result)
+
+        # transform just a node, not the entire document
+        node_result = obj.bar_node.xsl_transform(xsl=identity_transform)
+        self.assertEqual(obj.bar_node, node_result)
+
+        # partial document without pre-compiled xsl
+        node_result = obj.bar_node.xsl_transform(xsl=self.IDENTITY_XSL)
+        self.assertEqual(obj.bar_node, node_result)
+
 
-        self.FILE.close()
-        # not yet tested: xsl with parameters
 
 
 # NOTE: using TestXsl fixture text for the init tests
@@ -213,39 +264,39 @@ class TestXmlObject(unittest.TestCase):
         self.obj = xmlmap.load_xmlobject_from_string(TestXsl.FIXTURE_TEXT)
 
     def test__unicode(self):
-        u = self.obj.__unicode__()
-        self.assert_("42 13" in u)
+        stu = u(self.obj)
+        self.assert_("42 13" in stu)
 
     def test__string(self):
-        self.assertEqual('42 13', self.obj.__string__())
+        self.assertEqual(b'42 13', self.obj.__string__())
 
         # convert xml with unicode content
         obj = xmlmap.load_xmlobject_from_string(u'<text>unicode \u2026</text>')
-        self.assertEqual('unicode &#8230;', obj.__string__())
+        self.assertEqual(b'unicode &#8230;', obj.__string__())
 
     def test_serialize_tostring(self):
         xml_s = self.obj.serialize()
-        self.assert_("<baz>42</baz>" in xml_s)
+        self.assert_(b"<baz>42</baz>" in xml_s)
 
         # serialize subobjects
         baz = self.obj.node.xpath('bar/baz[1]')[0]
         baz_obj = xmlmap.XmlObject(baz)
-        self.assertEqual('<baz>42</baz>', baz_obj.serialize().strip())
+        self.assertEqual(b'<baz>42</baz>', baz_obj.serialize().strip())
 
     def test_serialize_tofile(self):
         FILE = tempfile.TemporaryFile()
         self.obj.serialize(stream=FILE)
         FILE.flush()
         FILE.seek(0)
-        self.assert_("<baz>13</baz>" in FILE.read())
+        self.assert_(b"<baz>13</baz>" in FILE.read())
         FILE.close()
 
     def test_serializeDocument(self):
         obj = xmlmap.load_xmlobject_from_string(TestXmlObjectStringInit.VALID_XML)
         xmlstr = obj.serializeDocument()
-        self.assert_("encoding='UTF-8'" in xmlstr,
+        self.assert_(b"encoding='UTF-8'" in xmlstr,
             "XML generated by serializeDocument should include xml character encoding")
-        self.assert_('<!DOCTYPE a' in xmlstr,
+        self.assert_(b'<!DOCTYPE a' in xmlstr,
             "XML generated by serializeDocument should include DOCTYPE declaration")
 
     def test_isvalid(self):
