@@ -20,6 +20,8 @@ from datetime import datetime, date
 import tempfile
 import unittest
 
+from six.moves.builtins import str as text
+
 import eulxml.xmlmap.core as xmlmap
 
 
@@ -328,6 +330,42 @@ class TestFields(unittest.TestCase):
         # check required
         self.assertFalse(obj._fields['missing'].required)
 
+    def testFloatField(self):
+        class TestObject(xmlmap.XmlObject):
+            val = xmlmap.IntegerField('bar[2]/baz', required=True)
+            count = xmlmap.IntegerField('count(//bar)')
+            missing = xmlmap.IntegerField('missing')
+            nan = xmlmap.IntegerField('@id')
+
+        obj = TestObject(self.fixture)
+        self.assertEqual(obj.val, 13.0)
+        self.assertEqual(obj.count, 2.0)
+        self.assertEqual(obj.missing, None)
+        self.assertEqual(obj.nan, None)
+        # undefined if >1 matched nodes
+
+        # set an integer value
+        obj.val = 14.0
+        # check that new value is set in the node
+        self.assertEqual(obj.node.xpath('number(bar[2]/baz)'), 14.0)
+        # check that new value is accessible via descriptor
+        self.assertEqual(obj.val, 14.0)
+
+        # check required
+        self.assertTrue(obj._fields['val'].required)
+
+    def testFloatListField(self):
+        class TestObject(xmlmap.XmlObject):
+            vals = xmlmap.IntegerListField('bar/baz')
+            missing = xmlmap.IntegerListField('missing', required=False)
+
+        obj = TestObject(self.fixture)
+        self.assertEqual(obj.vals, [42.0, 13.0])
+        self.assertEqual(obj.missing, [])
+
+        # check required
+        self.assertFalse(obj._fields['missing'].required)
+
     def testItemField(self):
         class TestObject(xmlmap.XmlObject):
             letter = xmlmap.ItemField('substring(bar/baz, 1, 1)')
@@ -348,6 +386,9 @@ class TestFields(unittest.TestCase):
             num_bool2 = xmlmap.SimpleBooleanField('boolean/num2', 1, 0)
             opt_elem_bool = xmlmap.SimpleBooleanField('boolean/opt', 'yes', None)
             opt_attr_bool = xmlmap.SimpleBooleanField('boolean/@opt', 'yes', None)
+            # xml not present at all should not result in errors
+            missing_bool = xmlmap.SimpleBooleanField('boolean/missing', 'yes', None)
+            missing_bool2 = xmlmap.SimpleBooleanField('boolean/missing', 'yes', 'no')
 
         #obj = TestObject(self.fixture.documentElement)
         obj = TestObject(self.fixture)
@@ -357,6 +398,8 @@ class TestFields(unittest.TestCase):
         self.assertEqual(obj.num_bool2, False)
         self.assertEqual(obj.opt_elem_bool, False)
         self.assertEqual(obj.opt_attr_bool, False)
+        self.assertEqual(obj.missing_bool, False)
+        self.assertEqual(obj.missing_bool2, None)
 
         # set text boolean
         obj.txt_bool1 = False
@@ -463,7 +506,7 @@ class TestFields(unittest.TestCase):
         self.assertEqual(obj.node.xpath('string(date)'), today.isoformat())
         # alternate format
         obj.dates[1] = today
-        self.assertEqual(obj.node.xpath('string(date[1])'), unicode(today))
+        self.assertEqual(obj.node.xpath('string(date[1])'), text(today))
 
 
     def testSchemaField(self):
@@ -978,5 +1021,3 @@ class TestNodeList(unittest.TestCase):
             % len(self.obj.nodes))
         self.assertEqual(node.id, self.obj.nodes[0].id)
         self.assertEqual(node.parts, self.obj.nodes[0].parts)
-
-
